# Copyright (c) 2016, Patrick Uiterwijk <patrick@puiterwijk.org>
# All rights reserved.
#
# This file is part of Basset.
#
# Basset is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Basset is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Basset.  If not, see <http://www.gnu.org/licenses/>.

import requests

from basset.score.base import ScorePlugin


class IPScore(ScorePlugin):
    name = 'ip'

    def get_score(self, action, time, data):
        scores = {}

        if 'request_headers' in data:
            ip = data['request_headers']['x-forwarded-for']
            ipinfo = self._get_rdap_data(ip)

            scores['ip_country'] = self.get_ip_country_score(ipinfo)
            scores['ip_owner'] = self.get_ip_owner_score(ipinfo)

        return scores

    def _get_rdap_data(self, ip):
        url = 'http://rdap.apnic.net/ip/%s' % ip
        return requests.get(url).json()

    def get_ip_country_score(self, ipinfo):
        mapping = {}
        for option in self.config:
            if option.startswith('ip_country_'):
                mapping[option[len('ip_country_'):]] = self.config[option]
        if ipinfo['country'] in mapping:
            return int(mapping[ipinfo['country']])
        else:
            return 0

    def get_ip_owner_score(self, ipinfo):
        mapping = {}
        for option in self.config:
            if option.startswith('ip_owner_'):
                mapping[option[len('ip_owner_'):]] = self.config[option]
        for owner in mapping:
            if owner in ipinfo['name'].lower():
                return int(mapping[owner])
        else:
            return 0
